@@ -8,6 +8,7 @@
 #include <string.h>
 
 #include "soup-message-body.h"
+#include "soup.h"
 
 /**
  * SECTION:soup-message-body
@@ -328,20 +329,7 @@ soup_buffer_get_as_bytes (SoupBuffer *buffer)
 					   copy);
 }
 
-GType
-soup_buffer_get_type (void)
-{
-	static volatile gsize type_volatile = 0;
-
-	if (g_once_init_enter (&type_volatile)) {
-		GType type = g_boxed_type_register_static (
-			g_intern_static_string ("SoupBuffer"),
-			(GBoxedCopyFunc) soup_buffer_copy,
-			(GBoxedFreeFunc) soup_buffer_free);
-		g_once_init_leave (&type_volatile, type);
-	}
-	return type_volatile;
-}
+G_DEFINE_BOXED_TYPE (SoupBuffer, soup_buffer, soup_buffer_copy, soup_buffer_free)
 
 
 /**
@@ -544,11 +532,8 @@ void
 soup_message_body_truncate (SoupMessageBody *body)
 {
 	SoupMessageBodyPrivate *priv = (SoupMessageBodyPrivate *)body;
-	GSList *iter;
 
-	for (iter = priv->chunks; iter; iter = iter->next)
-		soup_buffer_free (iter->data);
-	g_slist_free (priv->chunks);
+	g_slist_free_full (priv->chunks, (GDestroyNotify)soup_buffer_free);
 	priv->chunks = priv->last = NULL;
 	priv->base_offset = 0;
 
@@ -756,17 +741,4 @@ soup_message_body_free (SoupMessageBody *body)
 	}
 }
 
-GType
-soup_message_body_get_type (void)
-{
-	static volatile gsize type_volatile = 0;
-
-	if (g_once_init_enter (&type_volatile)) {
-		GType type = g_boxed_type_register_static (
-			g_intern_static_string ("SoupMessageBody"),
-			(GBoxedCopyFunc) soup_message_body_copy,
-			(GBoxedFreeFunc) soup_message_body_free);
-		g_once_init_leave (&type_volatile, type);
-	}
-	return type_volatile;
-}
+G_DEFINE_BOXED_TYPE (SoupMessageBody, soup_message_body, soup_message_body_copy, soup_message_body_free)
