@@ -15,7 +15,7 @@
 
 /**
  * SECTION:soup-value-utils
- * @short_description: GValue utilities
+ * @short_description: #GValue utilities
  *
  * These methods are useful for manipulating #GValue<!-- -->s, and in
  * particular, arrays and hash tables of #GValue<!-- -->s, in a
@@ -23,8 +23,6 @@
  *
  * They are written for use with soup-xmlrpc, but they also work with
  * types not used by XML-RPC.
- *
- * Deprecated: Use #GVariant API instead.
  **/
 
 /**
@@ -36,8 +34,6 @@
  * Copies an argument of type @type from @args into @val. @val will
  * point directly to the value in @args rather than copying it, so you
  * must g_value_copy() it if you want it to remain valid.
- *
- * Deprecated: Use #GVariant API instead.
  **/
 
 /**
@@ -49,13 +45,8 @@
  * Extracts a value of type @type from @val into @args. The return
  * value will point to the same data as @val rather than being a copy
  * of it.
- *
- * Deprecated: Use #GVariant API instead.
  **/
 
-/* This whole file is deprecated and replaced by GVariant API */
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-
 static void
 soup_value_hash_value_free (gpointer val)
 {
@@ -71,8 +62,6 @@ soup_value_hash_value_free (gpointer val)
  *
  * Return value: (element-type utf8 GValue) (transfer full): a new
  * empty #GHashTable
- *
- * Deprecated: Use #GVariant API instead.
  **/
 GHashTable *
 soup_value_hash_new (void)
@@ -112,8 +101,6 @@ soup_value_hash_insert_valist (GHashTable *hash, const char *first_key,
  *
  * Return value: (element-type utf8 GValue) (transfer full): a new
  * #GHashTable, initialized with the given values
- *
- * Deprecated: Use #GVariant API instead.
  **/
 GHashTable *
 soup_value_hash_new_with_vals (const char *first_key, ...)
@@ -136,8 +123,6 @@ soup_value_hash_new_with_vals (const char *first_key, ...)
  *
  * Inserts @value into @hash. (Unlike with g_hash_table_insert(), both
  * the key and the value are copied).
- *
- * Deprecated: Use #GVariant API instead.
  **/
 void
 soup_value_hash_insert_value (GHashTable *hash, const char *key, GValue *value)
@@ -158,8 +143,6 @@ soup_value_hash_insert_value (GHashTable *hash, const char *key, GValue *value)
  *
  * Inserts the provided value of type @type into @hash. (Unlike with
  * g_hash_table_insert(), both the key and the value are copied).
- *
- * Deprecated: Use #GVariant API instead.
  **/
 void
 soup_value_hash_insert (GHashTable *hash, const char *key, GType type, ...)
@@ -183,8 +166,6 @@ soup_value_hash_insert (GHashTable *hash, const char *key, GType type, ...)
  * Inserts the given data into @hash. As with
  * soup_value_hash_insert(), the keys and values are copied rather
  * than being inserted directly.
- *
- * Deprecated: Use #GVariant API instead.
  **/
 void
 soup_value_hash_insert_vals (GHashTable *hash, const char *first_key, ...)
@@ -208,8 +189,6 @@ soup_value_hash_insert_vals (GHashTable *hash, const char *first_key, ...)
  *
  * Return value: %TRUE if @hash contained a value with key @key and
  * type @type, %FALSE if not.
- *
- * Deprecated: Use #GVariant API instead.
  **/
 gboolean
 soup_value_hash_lookup (GHashTable *hash, const char *key, GType type, ...)
@@ -243,8 +222,6 @@ soup_value_hash_lookup (GHashTable *hash, const char *key, GType type, ...)
  * initialize each destination variable to a reasonable default
  * value, since there is no way to tell which keys were found
  * and which were not.
- *
- * Deprecated: Use #GVariant API instead.
  **/
 gboolean
 soup_value_hash_lookup_vals (GHashTable *hash, const char *first_key, ...)
@@ -276,6 +253,10 @@ soup_value_hash_lookup_vals (GHashTable *hash, const char *first_key, ...)
 }
 
 
+#ifdef G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+#endif
+
 /**
  * soup_value_array_from_args:
  * @args: arguments to create a #GValueArray from
@@ -285,10 +266,7 @@ soup_value_hash_lookup_vals (GHashTable *hash, const char *first_key, ...)
  * by %G_TYPE_INVALID. (The array will contain copies of the provided
  * data rather than pointing to the passed-in data directly.)
  *
- * Return value: (nullable): a new #GValueArray, or %NULL if an error
- * occurred.
- *
- * Deprecated: Use #GVariant API instead.
+ * Return value: a new #GValueArray, or %NULL if an error occurred.
  **/
 GValueArray *
 soup_value_array_from_args (va_list args)
@@ -316,15 +294,13 @@ soup_value_array_from_args (va_list args)
  * same memory as the values in the array.
  *
  * Return value: success or failure
- *
- * Deprecated: Use #GVariant API instead.
  **/
 gboolean
 soup_value_array_to_args (GValueArray *array, va_list args)
 {
 	GType type;
 	GValue *value;
-	guint i;
+	int i;
 
 	for (i = 0; i < array->n_values; i++) {
 		type = va_arg (args, GType);
@@ -345,8 +321,6 @@ soup_value_array_to_args (GValueArray *array, va_list args)
  * g_value_array_new(), for naming consistency purposes.)
  *
  * Return value: a new %GValueArray
- *
- * Deprecated: Use #GVariant API instead.
  **/
 GValueArray *
 soup_value_array_new (void)
@@ -380,8 +354,6 @@ soup_value_array_append_valist (GValueArray *array,
  * into it.
  *
  * Return value: a new %GValueArray
- *
- * Deprecated: Use #GVariant API instead.
  **/
 GValueArray *
 soup_value_array_new_with_vals (GType first_type, ...)
@@ -406,8 +378,6 @@ soup_value_array_new_with_vals (GType first_type, ...)
  * Inserts the provided value of type @type into @array as with
  * g_value_array_insert(). (The provided data is copied rather than
  * being inserted directly.)
- *
- * Deprecated: Use #GVariant API instead.
  **/
 void
 soup_value_array_insert (GValueArray *array, guint index_, GType type, ...)
@@ -430,8 +400,6 @@ soup_value_array_insert (GValueArray *array, guint index_, GType type, ...)
  * Appends the provided value of type @type to @array as with
  * g_value_array_append(). (The provided data is copied rather than
  * being inserted directly.)
- *
- * Deprecated: Use #GVariant API instead.
  **/
 void
 soup_value_array_append (GValueArray *array, GType type, ...)
@@ -455,8 +423,6 @@ soup_value_array_append (GValueArray *array, GType type, ...)
  * Appends the provided values into @array as with
  * g_value_array_append(). (The provided data is copied rather than
  * being inserted directly.)
- *
- * Deprecated: Use #GVariant API instead.
  **/
 void
 soup_value_array_append_vals (GValueArray *array, GType first_type, ...)
@@ -480,8 +446,6 @@ soup_value_array_append_vals (GValueArray *array, GType first_type, ...)
  *
  * Return value: %TRUE if @array contained a value with index @index_
  * and type @type, %FALSE if not.
- *
- * Deprecated: Use #GVariant API instead.
  **/
 gboolean
 soup_value_array_get_nth (GValueArray *array, guint index_, GType type, ...)
@@ -499,6 +463,10 @@ soup_value_array_get_nth (GValueArray *array, guint index_, GType type, ...)
 	return TRUE;
 }
 
+#ifdef G_GNUC_END_IGNORE_DEPRECATIONS
+G_GNUC_END_IGNORE_DEPRECATIONS
+#endif
+
 static GByteArray *
 soup_byte_array_copy (GByteArray *ba)
 {
@@ -520,10 +488,6 @@ soup_byte_array_free (GByteArray *ba)
  *
  * glib did not used to define a #GType for #GByteArray, so libsoup
  * defines this one itself.
- *
- * Deprecated: Use #GVariant API instead.
  **/
 typedef GByteArray SoupByteArray;
 G_DEFINE_BOXED_TYPE (SoupByteArray, soup_byte_array, soup_byte_array_copy, soup_byte_array_free)
-
-G_GNUC_END_IGNORE_DEPRECATIONS
